package TiVo::Slice::Record::StationDay;

use strict;
use base qw(TiVo::Slice::Record);
use TiVo::Slice::Number;

our $VERSION =
    (split / /, q$Id: StationDay.pm,v 1.1 2001/12/02 11:00:45 grant Exp $)[2];

sub field_defs {
    (
     station   => [0x42, 'StationIndex'],
     station2  => [0x46, 'StationIndex'], # used inside detail
     program   => [0x42, 'ProgramIndex'],
     slot      => [0x4A, 'SlotNumber'],
     day       => [0x44, 'Number'],
     date      => [0x48, 'Number'], # inside detail
     time      => [0x4C, 'Number'],
     duration  => [0x50, 'Number'],
    );
}

my $slot_number_start = 10;

sub new {
    my $class = shift;
    my $self = $class->SUPER::new(@_);
    $self->_code(0x106);
    $self->{slot_number} = $slot_number_start;
    $self->{slot_list} = [];
    $self->{slot_details} = [];
    return $self;
}

sub add_showing {
    my $self = shift;
    my %fields = (
                  station => $self->get('station'),
                  day     => $self->get('day'),
                  @_,
                 );

    # each showing gets a slot number
    my $slotno = $self->{slot_number}++;

    # add to slot list
    my $slot = $self->_new_fields(slot => $slotno);
    push @{$self->{slot_list}}, $slot;

    # change station field type (a different code is used within the detail)
    $fields{station2} = $fields{station};
    # copy day to date
    $fields{date} = $fields{day};

    # add to slot detail
    my @detail_fields = qw( station2 program date time duration );
    my @details = $self->_new_fields(map { $_ => $fields{$_} } @detail_fields);
    push @{$self->{slot_details}}, [ $slot->value, \@details ];
}

sub _fields {
    my $self = shift;

    # slot details: slot number, detail, 00, repeat
    my @details = 
        map { $_->[0], $self->_pack_fields(@{$_->[1]}), pack("C", 0x00) }
            @{$self->{slot_details}};
    # we don't want the last 00 since the end of record already has one
    pop @details;

    # regular fields, slot list and end marker, slot details
    return( 
           $self->SUPER::_fields,
           $self->_pack_fields(@{$self->{slot_list}}),
           pack("C", 0x00),
           @details,
          );
}

1;




