# read-only access to the station list
package TiVo::Stations;

use strict;
use TiVo::Config;

our $VERSION =
    (split / /, q$Id: Stations.pm,v 1.2 2001/12/02 11:01:38 grant Exp $)[2];

sub new {
    my $class = shift;
    my $self = {};
    bless $self, $class;
    $self->_init;
    return $self;
}

# load the stations file
# make $self->{stations}, a hash of hashes
# key is serverid, value is a hash of everything else, keyed by column name
sub _init {
    my $self = shift;
    my $conf = TiVo::Config->new;
    my $stationsfile = $conf->guidedir . '/stations.txt';
    die "$stationsfile not found" unless -e $stationsfile;
    open(my $file, $stationsfile) or die "failed open of $stationsfile ($!)";
    my (%column_index, $serverid_index);
    while (<$file>) {
        if (/^# TiVo::Stations header # (.*)$/) {
            my @columns = split(/\s*,\s*/, $1);
            for my $i (0 .. $#columns) {
                if ($columns[$i] eq 'serverid') {
                    $serverid_index = $i;
                }
                else {
                    $column_index{$columns[$i]} = $i;
                }
            }
        }
        next if /^\s*\#/;       # skip comment lines
        next if /^\s*$/;        # skip blank lines
        chomp;
        s/#.*$//;               # strip end-of-line comments
        s/\s*$//;               # strip end-of-line whitespace
        my @row = split /\s*,\s*/;
        die "no header before data" unless $serverid_index;
        my %station = map { $_ => $row[$column_index{$_}] } keys %column_index;
        $self->{stations}->{$row[$serverid_index]} = \%station;
    }
    close($file) or die "failed close ($!)";
    $self->{columns} = \%column_index; # save it for is_column
}

# list of all stations (server ids)
sub all {
    my $self = shift;
    return sort keys %{$self->{stations}};
}

# check if column exists
sub is_column {
    my $self = shift;
    my $maybecolumn = shift;
    return exists $self->{columns}->{$maybecolumn};
}

# any column by server id
AUTOLOAD {
    my $self = shift;
    my $id = shift;
    our $AUTOLOAD;
    my $key = $AUTOLOAD;
    $key =~ s/.*:://;
    return $self->{stations}->{$id}->{$key};
}

1;
