package TiVo::Zap2it::Agent;

use strict;
use base qw(TiVo::Web::Agent);
use Carp;
use TiVo::Config;
use TiVo::Stations;
use LWP::UserAgent;
use HTTP::Request::Common;
use HTTP::Cookies;
use HTTP::Request;

our $VERSION =
    (split / /, q$Id: Agent.pm,v 1.3 2001/12/02 11:01:45 grant Exp $)[2];

sub new {
    my $class = shift;
    my $self = $class->SUPER::new(@_);
    $self->init;
    return $self;
}

sub init {
    my $self = shift;
    my $conf = TiVo::Config->new;
    my $postal = $conf->postalcode;
    my $provider = $conf->provider;
    my $listings_string = "ZipCode=$postal&ProviderID=$provider&vstr%5Fid=";
    my $jar = HTTP::Cookies->new;
    $jar->set_cookie(
                     0, 
                     TVListings => $listings_string,
                     '/', 'tvlistings2.zap2it.com', 80, 0, 0,
                     time() + 60*60*24,
                     0, {}
                    );
    my $agent = LWP::UserAgent->new;
    $agent->cookie_jar($jar);

    my $stations = TiVo::Stations->new;
    die "stations file does not have a zap2it_id column"
        unless $stations->is_column('zap2it_id');
    
    $self->{agent} = $agent;
    $self->{jar} = $jar;
    $self->{stations} = $stations;
}

sub getpage {
    my $self = shift;
    my ($station, $day) = @_;
    $day =~ s|(\d{4})(\d{2})(\d{2})|$1/$2/$3| or croak "bad day";
    my $domain = 'http://tvlistings2.zap2it.com';
    my $path = 'listings_redirect.asp';
    my $agent = $self->{agent};
    my $zapstation = $self->{stations}->zap2it_id($station);
    return unless $zapstation;
    my $response = $agent->request(
                                   POST "$domain/$path",
                                   [
                                    startDay => $day,
                                    duration => 1,
                                    startTime => 0,
                                    category => 0,
                                    displayType => 'Text',
                                    station => $zapstation,
                                    goButton => 'GO',
                                   ],
                                  );
    $agent->cookie_jar->extract_cookies($response);
    $path = $response->header('Location');
    
    $response = $agent->request(GET "$domain/$path");
    return $response->content;
}

1;
